==> apache-camel-quarkus-3.14.0-src.zip: camel-quarkus-3.14.0/integration-tests/pgevent/src/test/java/org/apache/camel/quarkus/component/pgevent/it/PgeventTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.pgevent.it;

import io.quarkus.test.common.WithTestResource;
import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.equalTo;

@QuarkusTest
@WithTestResource(PgEventTestResource.class)
@TestHTTPEndpoint(PgeventResource.class)
class PgeventTest {

    @Test
    public void testPublish() {
        RestAssured.given()
                .get("/Test Camel PGEvent")
                .then()
                .statusCode(202)
                .body(equalTo("Test Camel PGEvent"));
    }

    @Test
    public void testPublishWithDatasource() {
        RestAssured.given()
                .get("/datasource/Test Camel PGEvent with datasource")
                .then()
                .statusCode(202)
                .body(equalTo("Test Camel PGEvent with datasource"));
    }
}

==> apache-camel-quarkus-3.30.0-src.zip: camel-quarkus-3.30.0/integration-tests/pgevent/src/test/java/org/apache/camel/quarkus/component/pgevent/it/PgeventTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.pgevent.it;

import io.quarkus.test.common.QuarkusTestResource;
import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.restassured.RestAssured;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.equalTo;

@QuarkusTest
@QuarkusTestResource(PgEventTestResource.class)
@TestHTTPEndpoint(PgeventResource.class)
class PgeventTest {

    @Test
    public void testPublish() {
        RestAssured.given()
                .get("/Test Camel PGEvent")
                .then()
                .statusCode(202)
                .body(equalTo("Test Camel PGEvent"));
    }

    @Test
    public void testPublishWithDatasource() {
        RestAssured.given()
                .get("/datasource/Test Camel PGEvent with datasource")
                .then()
                .statusCode(202)
                .body(equalTo("Test Camel PGEvent with datasource"));
    }
}
